@@ -1,5 +1,6 @@
 import src.jadecobra.tester
 import src.jadecobra.versioning
+import os
 
 
 class TestJadeCobraVersioning(src.jadecobra.tester.TestCase):
@@ -17,8 +18,9 @@ class TestJadeCobraVersioning(src.jadecobra.tester.TestCase):
                 '__name__',
                 '__package__',
                 '__spec__',
-                'os',
+                '__version__',
                 're',
+                'shutil',
                 'toolkit',
             ]
         )
@@ -55,18 +57,13 @@ class TestJadeCobraVersioning(src.jadecobra.tester.TestCase):
                 '__subclasshook__',
                 '__weakref__',
                 'get_pyproject_version',
-                'git_push',
                 'pyproject',
+                'pyproject_version_pattern',
                 'read_pyproject',
+                'remove_dist',
                 'semantic_version_pattern',
+                'update',
                 'update_module_version',
-                'update_pyproject_version'
+                'update_pyproject_version',
             ]
-        )
-
-    # def test_update_version(self):
-    #     version = src.jadecobra.versioning.Version()
-    #     self.assertEqual(
-    #         version.get_pyproject_version(),
-    #         ('0.3.', '2'),
-    #     )
+        )
\ No newline at end of file
